@@ -21,26 +21,26 @@ which = c("all", "single", "3D" ),
   maxVal <- max(unlist(sapply(modList, function(x) x$DATA[, 2])), na.rm = TRUE)
   CYC <- unique(as.vector(unlist(sapply(modList, function(x) x$DATA[, 1]))))
 
-  LEN <- length(modList)
+  LEN <- length(modList)   
     
   if (is.null(col)) {
-    colvec <- rep(1, LEN)     
-    if (class(object)[2] == "replist") colvec <- gl(attr(object, "nlevels"), 1)
+    colvec <- rep(1, LEN)      
+    if (class(object)[2] == "replist") colvec <- rainbow(attr(object, "nlevels"))     
   } else colvec <- rep(col, length.out = LEN)  
   
   if (!add && which == "3D") {     
     plot3d(x = CYC, y = 1:LEN, z = maxVal, type = "n", axes = FALSE, box = FALSE,
-           xlab = "", ylab = "", zlab = "", zlim = c(0, 1.1 * maxVal))       
+           xlab = "", ylab = "", zlab = "", zlim = c(0, 1.1 * maxVal), ...)       
     
     for (i in 1:LEN) {
      DATA <- modList[[i]]$DATA        
      CC <- complete.cases(DATA[, 2])       
      DATA <- DATA[CC, ] 
      FITTED <- fitted(modList[[i]])     
-     if (nrow(DATA) > 0) points3d(x = DATA[, 1], y = i, z = DATA[, 2], col = colvec[i]) else next
+     if (nrow(DATA) > 0) points3d(x = DATA[, 1], y = i, z = DATA[, 2], col = colvec[i], ...) else next
      if (is.null(FITTED)) next
-     if (class(modList)[2] != "replist") lines3d(x = DATA[, 1], y = i, z = FITTED[CC], col = colvec[i])
-     else lines3d(x = DATA[CYC, 1], y = i, z = FITTED[CYC], col = colvec[i])
+     if (class(modList)[2] != "replist") lines3d(x = DATA[, 1], y = i, z = FITTED[CC], col = colvec[i], ...)
+     else lines3d(x = DATA[CYC, 1], y = i, z = FITTED[CYC], col = colvec[i], ...)
     }     
     
     axis3d('x', at = pretty(CYC), cex = 0.5)
@@ -69,16 +69,16 @@ which = c("all", "single", "3D" ),
     FITTED <- fitted(modList[[i]])[CC] 
     
     if (!add && which == "single") {         
-      TRY <- try(plot(DATA, xlim = c(xlim[1], xlim[2]), main = modList[[i]]$names, cex.main = 0.7, type = "n", xlab = FALSE, ylab = FALSE, xaxt = "n", yaxt = "n"), silent = TRUE)
+      TRY <- try(plot(DATA, xlim = c(xlim[1], xlim[2]), main = modList[[i]]$names, cex.main = 0.7, type = "n", xlab = FALSE, ylab = FALSE, xaxt = "n", yaxt = "n", ...), silent = TRUE)
       if (inherits(TRY, "try-error")) next
     } else  TRY <- NA   
    
       points(DATA, col = colvec[i], ...)
        
       if (is.null(modList[[i]]$isReps)) {             
-        if (!is.null(FITTED)) lines(DATA[, 1], FITTED[CC], col = colvec[i])      
+        if (!is.null(FITTED)) lines(DATA[, 1], FITTED[CC], col = colvec[i], ...)      
       } else {          
-      if (!is.null(FITTED)) lines(DATA[CYC, 1], FITTED[CYC], col = colvec[i])       
+      if (!is.null(FITTED)) lines(DATA[CYC, 1], FITTED[CYC], col = colvec[i], ...)       
       }      
       
       if (confband != "none" || errbar == "conf") {
@@ -95,8 +95,8 @@ which = c("all", "single", "3D" ),
      
         STAT <- switch(errbar, sd = apply(DATA2, 1, function(x) sd(x, na.rm = TRUE)), 
                             se = apply(DATA2, 1, function(x) sd(x, na.rm = TRUE)/sqrt(length(x[complete.cases(x)]))))
-        if (errbar == "conf") arrows(DATA[, 1], CONFINT$Lower, DATA[, 1], CONFINT$Upper, angle = 90, code = 3, col = colvec[i], length = 0.05)
-        else arrows(DATA[, 1], FITTED + STAT, DATA[, 1], FITTED - STAT, angle = 90, code = 3, col = colvec[i], length = 0.05)            
+        if (errbar == "conf") arrows(DATA[, 1], CONFINT$Lower, DATA[, 1], CONFINT$Upper, angle = 90, code = 3, col = colvec[i], length = 0.05, ...)
+        else arrows(DATA[, 1], FITTED + STAT, DATA[, 1], FITTED - STAT, angle = 90, code = 3, col = colvec[i], length = 0.05, ...)            
       }      
     } 
 }
